#  Zelda
> an nlp training framework，基础架构基于allennlp


## 目前支持模型
text classifier：  
1. [average_pooling_text_classifier](https://github.com/whu-SpongeBob/spongenlp/blob/master/spongenlp/models/text_classifier/aver_pooling_text_classifier.py)  
2. [bert_text_classifier](https://github.com/whu-SpongeBob/spongenlp/blob/master/spongenlp/models/text_classifier/bert_text_classifier_model.py)  
3. [cnn_text_classifier](https://github.com/whu-SpongeBob/spongenlp/blob/master/spongenlp/models/text_classifier/cnn_test_classifier.py)  

intent slot multitask:
1. [sf_id](https://github.com/whu-SpongeBob/spongenlp/blob/master/spongenlp/models/intent_slot/sf_id_intent_slot_model.py)

## 论文复现
1. [A Novel Bi-directional Interrelated Model for Joint Intent Detection and
Slot Filling
](https://github.com/whu-SpongeBob/spongenlp/blob/master/spongenlp/models/intent_slot/sf_id_intent_slot_model.py)